﻿Imports System
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Shapes
Imports System.Windows.Documents
Imports System.Windows.Media

Public Class ShapesPaginator
    Inherits Documents.DocumentPaginator

    Private m_PageSize As Size

    ' Save the page size.
    Public Sub New(ByVal page_size As Size)
        m_PageSize = page_size
    End Sub

    ' Return the needed page.
    Public Overrides Function GetPage(ByVal pageNumber As Integer) As System.Windows.Documents.DocumentPage
        Const WID As Double = 600
        Const HGT As Double = 800

        Dim drawing_grid As New Grid()
        drawing_grid.Width = m_PageSize.Width
        drawing_grid.Height = m_PageSize.Height

        Select Case pageNumber
            Case 0 ' Ellipse
                Dim ell As New Ellipse()
                ell.Fill = Brushes.Orange
                ell.Stroke = Brushes.Blue
                ell.StrokeThickness = 1
                ell.HorizontalAlignment = HorizontalAlignment.Center
                ell.VerticalAlignment = VerticalAlignment.Center
                ell.Width = WID
                ell.Height = HGT
                drawing_grid.Children.Add(ell)

            Case 1 ' Triangle.
                Dim triangle As New Polygon()
                triangle.Fill = Brushes.Yellow
                triangle.Stroke = Brushes.Red
                triangle.StrokeThickness = 10
                triangle.HorizontalAlignment = HorizontalAlignment.Center
                triangle.VerticalAlignment = VerticalAlignment.Center

                Dim dash_array As New DoubleCollection()
                dash_array.Add(2)
                triangle.StrokeDashArray = dash_array

                Dim triangle_pts As New PointCollection()
                triangle_pts.Add(New Point(WID / 2, 0))
                triangle_pts.Add(New Point(WID, HGT))
                triangle_pts.Add(New Point(0, HGT))
                triangle.Points = triangle_pts
                drawing_grid.Children.Add(triangle)

            Case 2 ' Diamond.
                Dim diamond As New Polygon()
                diamond.Fill = Brushes.LightBlue
                diamond.Stroke = Brushes.Green
                diamond.StrokeThickness = 20
                diamond.HorizontalAlignment = HorizontalAlignment.Center
                diamond.VerticalAlignment = VerticalAlignment.Center
                diamond.StrokeLineJoin = PenLineJoin.Round

                Dim diamond_pts As New PointCollection()
                diamond_pts.Add(New Point(WID / 2, 0))
                diamond_pts.Add(New Point(WID, HGT / 2))
                diamond_pts.Add(New Point(WID / 2, HGT))
                diamond_pts.Add(New Point(0, HGT / 2))
                diamond.Points = diamond_pts
                drawing_grid.Children.Add(diamond)

            Case 3 ' Star.
                Dim star As New Polygon()
                star.Fill = Brushes.Orange
                star.FillRule = FillRule.Nonzero
                star.Stroke = Brushes.Black
                star.StrokeThickness = 10
                star.HorizontalAlignment = HorizontalAlignment.Center
                star.VerticalAlignment = VerticalAlignment.Center

                Dim star_pts As New PointCollection()
                Dim theta As Double = -System.Math.PI / 2
                Dim dtheta As Double = System.Math.PI * 4 / 5
                For i As Integer = 0 To 4
                    star_pts.Add(New Point( _
                        WID / 2 + WID / 2 * System.Math.Cos(theta), _
                        HGT / 2 + WID / 2 * System.Math.Sin(theta)))
                    theta += dtheta
                Next i
                star.Points = star_pts
                drawing_grid.Children.Add(star)
        End Select

        ' Arrange to make the controls draw themselves.
        Dim rect As New Rect(New Point(0, 0), m_PageSize)
        drawing_grid.Arrange(Rect)

        ' Return a DocumentPage wrapping the grid.
        Return New DocumentPage(drawing_grid)
    End Function

    ' If pagination is in progress and PageCount is not final, return False.
    ' If pagination is complete and PageCount is final, return True.
    ' In this example, there is no pagination to do.
    Public Overrides ReadOnly Property IsPageCountValid() As Boolean
        Get
            Return True
        End Get
    End Property

    ' The number of pages paginated so far.
    ' This example has exactly 4 pages.
    Public Overrides ReadOnly Property PageCount() As Integer
        Get
            Return 4
        End Get
    End Property

    ' The suggested page size.
    Public Overrides Property PageSize() As System.Windows.Size
        Get
            Return m_PageSize
        End Get
        Set(ByVal value As System.Windows.Size)
            m_PageSize = value
        End Set
    End Property

    ' The element currently being paginated.
    Public Overrides ReadOnly Property Source() As System.Windows.Documents.IDocumentPaginatorSource
        Get
            Return Nothing
        End Get
    End Property
End Class
